@@ -1,4 +1,7 @@
 package Catalyst::Plugin::MemoryUsage;
+BEGIN {
+  $Catalyst::Plugin::MemoryUsage::VERSION = '0.1.0';
+}
 #ABSTRACT: Profile memory usage of requests
 
 use strict;
@@ -10,7 +13,14 @@ use MRO::Compat;
 
 use Memory::Usage;
 
-our $VERSION = '0.0.1';
+use Devel::CheckOS;
+
+our $os_not_supported = Devel::CheckOS::os_isnt( 'Linux' );
+
+if ( $os_not_supported ) {
+    warn "OS not supported by Catalyst::Plugin::MemoryUsage\n",
+         "\tStats will not be collected\n";
+}
 
 
 has memory_usage => (
@@ -25,20 +35,24 @@ sub reset_memory_usage {
     $self->memory_usage( Memory::Usage->new );
 }
 
+unless ( $os_not_supported ) {
+
 after execute => sub {
     my $c = shift;
 
-    $c->memory_usage->record( "after ". join " : ", @_ );
+    return if $os_not_supported;
+
+    $c->memory_usage->record( "after " . join " : ", @_ );
 };
 
 around prepare => sub {
     my $orig = shift;
     my $self = shift;
 
-    my $c = $self->$orig( @_ );
+    my $c = $self->$orig(@_);
 
     $c->reset_memory_usage;
-    $c->memory_usage->record( 'preparing for the request' );
+    $c->memory_usage->record('preparing for the request');
 
     return $c;
 };
@@ -49,6 +63,8 @@ before finalize => sub {
     $c->log->debug( 'memory usage of request', $c->memory_usage->report );
 };
 
+}
+
 1;
 
 
@@ -63,7 +79,7 @@ Catalyst::Plugin::MemoryUsage - Profile memory usage of requests
 
 =head1 VERSION
 
-version 0.0.2
+version 0.1.0
 
 =head1 SYNOPSIS
 
@@ -131,6 +147,13 @@ method of that object:
 Discards the current C<Memory::Usage> object, along with its recorded data,
 and replaces it by a shiny new one.
 
+=head1 BUGS AND LIMITATIONS
+
+C<Memory::Usage>, which is the module C<Catalyst::Plugin::MemoryUsage> relies
+on to get its statistics, only work for Linux-based platforms. Consequently,
+for the time being C<Catalyst::Plugin::MemoryUsage> will not do anything
+on any other platform. This being said, patches are most welcome. :-)
+
 =head1 SEE ALSO
 
 L<Memory::Usage>
